package ai.pai.lensman.login;

import android.app.Activity;
import android.content.Intent;
import android.os.Bundle;
import android.support.v4.app.FragmentActivity;
import android.text.SpannableString;
import android.text.TextUtils;
import android.text.style.UnderlineSpan;
import android.view.View;
import android.widget.ImageView;
import android.widget.TextView;
import android.widget.Toast;

import com.android.common.utils.LogHelper;
import com.android.views.progressbar.ProgressWheel;

import org.json.JSONObject;

import ai.pai.lensman.R;
import ai.pai.lensman.activities.WebViewActivity;
import ai.pai.lensman.main.MainActivity;
import ai.pai.lensman.qrcode.QRCaptureActivity;
import butterknife.BindView;
import butterknife.ButterKnife;
import butterknife.OnClick;

public class LoginActivity extends FragmentActivity implements LoginContract.View{

    @BindView(R.id.wheel_wait_http)    ProgressWheel progressWheel;
    @BindView(R.id.tv_agree_protocol)  TextView protocolText;
    @BindView(R.id.iv_login_logo)      ImageView photoView;
    private LoginContract.Presenter presenter;
    private static final int SCAN_WX_LOGIN_CODE = 2000;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_login);
        ButterKnife.bind(this);
        SpannableString content = new SpannableString(getString(R.string.agree_protocol));
        content.setSpan(new UnderlineSpan(), 6, content.length(), 0);
        protocolText.setText(content);
        presenter = new LoginPresenter(this);
    }


    @Override
    protected void onResume() {
        super.onResume();
        presenter.start();
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
        presenter.stop();
    }

    @OnClick(R.id.btn_login)
    public void login(){
        Intent intent = new Intent(this, QRCaptureActivity.class);
        startActivityForResult(intent, SCAN_WX_LOGIN_CODE);
    }

    @OnClick(R.id.tv_agree_protocol)
    public void jump2Protocol(){
        Intent declareIntent = new Intent(this,WebViewActivity.class);
        declareIntent.putExtra("url","http://pai.ai/page/user_agreement");
        declareIntent.putExtra("title",getString(R.string.contract));
        startActivity(declareIntent);
    }

    @Override
    public void showLoginHint(String hint) {
        if(TextUtils.isEmpty(hint)){
            return;
        }
        Toast.makeText(this,hint,Toast.LENGTH_SHORT).show();
    }

    @Override
    public void showProgressView() {
        progressWheel.setVisibility(View.VISIBLE);
        progressWheel.startSpinning();
    }

    @Override
    public void hideProgressView() {
        progressWheel.stopSpinning();
        progressWheel.setVisibility(View.GONE);
    }

    @Override
    public void jumpMain() {
        startActivity(new Intent(this, MainActivity.class));
        finish();
    }

    @Override
    protected void onActivityResult(int requestCode, int resultCode, Intent data) {
        super.onActivityResult(requestCode,resultCode,data);
        if (resultCode == Activity.RESULT_OK) {
            if (data == null || data.getStringExtra("info") == null) {
                Toast.makeText(this,R.string.scan_login_qr_error,Toast.LENGTH_SHORT).show();
                return;
            }
            String qrInfo = data.getStringExtra("info");
            if(qrInfo.contains("unionid") && qrInfo.contains("token")){
                String json = qrInfo.replace("&quot;","'");
                LogHelper.d("czy","login scan qrcode = "+json);
                try{
                    JSONObject jsonObject = new JSONObject(json);
                    String unionid = jsonObject.getString("unionid");
                    String token = jsonObject.getString("token");
                    String lensmanType = jsonObject.getString("lensman_type");
                    presenter.login(unionid,token,lensmanType);
                    return;
                }catch (Exception e){
                    LogHelper.e("czy","login deal qrcode error"+e);
                }
            }
            Toast.makeText(this,R.string.scan_login_qr_error,Toast.LENGTH_SHORT).show();
        }
    }

}
