package ai.pai.lensman.login;

import android.os.AsyncTask;
import android.text.TextUtils;

import com.android.common.executors.ThreadExecutor;

import org.json.JSONObject;

import java.util.HashMap;

import ai.pai.lensman.base.BaseInteractor;
import ai.pai.lensman.db.Preferences;
import ai.pai.lensman.utils.HttpPostTask;
import ai.pai.lensman.utils.UrlContainer;

/**
 * Created by chengzhenyu on 2016/8/12.
 */
public class LoginInteractor implements BaseInteractor {

    private HttpPostTask loginTask;
    private InteractorListener<String> listener;
    private String unionid;
    private String token;

    public LoginInteractor(String unionid, String token, InteractorListener<String> listener) {
        this.unionid = unionid;
        this.token = token;
        this.listener = listener;
    }

    @Override
    public void startJob() {
        HashMap<String, String> params = new HashMap<>();
        params.put("unionid", unionid);
        params.put("token", token);

        loginTask = new HttpPostTask(params) {

            String lensmanId;
            String message;
            String userName;

            @Override
            protected boolean parseResponse(String response) {
                try {
                    JSONObject json = new JSONObject(response);
                    int status = json.getInt("status");
                    if (status == 200) {
                        JSONObject info = json.getJSONObject("data");
                        lensmanId = info.getString("user_id");
                        userName = info.getString("name");
                        if(TextUtils.isEmpty(userName)){
                            userName = info.getString("nickname");
                        }
                        if(TextUtils.isEmpty(userName)){
                            userName = info.getString("username");
                        }
                        return true;
                    } else {
                        message = json.getString("description");
                    }
                } catch (Exception e) {
                    e.printStackTrace();
                }
                return false;
            }

            @Override
            protected void onPostFail() {
                super.onPostFail();
                listener.onInteractFail(message);
            }

            @Override
            protected void onPostSuccess() {
                super.onPostSuccess();
                listener.onInteractSuccess(lensmanId);
                Preferences.getInstance().setLensManId(lensmanId);
                Preferences.getInstance().setUserName(userName);
            }
        };
        loginTask.executeOnExecutor(ThreadExecutor.getInstance().getExecutor(), UrlContainer.BOX_LENSMAN_LOGIN_URL);
    }

    @Override
    public void cancelJob() {
        cancelJob(loginTask);
    }

    private void cancelJob(HttpPostTask task) {
        if (task == null) {
            return;
        }
        if (task.getStatus() == AsyncTask.Status.RUNNING) {
            task.cancel(true);
        }
    }


}
